package
Version:
v1.0.1
Opens a new window with list of versions in this module.
Published: Aug 24, 2020
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type IPTopics struct {
Topics []string `json:"topics"`
}
type Topic struct {
Business string `json:"business"`
TopicName string `json:"topic_name"`
WorkerNum int `json:"worker_num"`
}
type TopicZkInfo struct {
Business string `json:"business"`
TopicName string `json:"topic_name"`
WorkerNum int `json:"worker_num"`
Workers []string `json:"workers"`
CreateTime string `json:"create_time,omitempty"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.